@@ -1,10 +1,11 @@
+from decimal import Decimal
 from typing import Tuple, List
 from lexnlp.extract.common.annotations.text_annotation import TextAnnotation
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2020, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/1.7.0/LICENSE"
-__version__ = "1.7.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/1.8.0/LICENSE"
+__version__ = "1.8.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
@@ -15,19 +16,22 @@ class DistanceAnnotation(TextAnnotation):
     create an object of DistanceAnnotation like
     cp = DistanceAnnotation(coords=(0, 100), value='101 km')
     """
-    def __init__(self,
-                 coords: Tuple[int, int],
-                 locale: str = 'en',
-                 text: str = None,
-                 amount: float = None,
-                 distance_type: str = None):
+    def __init__(
+        self,
+        coords: Tuple[int, int],
+        locale: str = 'en',
+        text: str = None,
+        amount: Decimal = None,
+        distance_type: str = None,
+    ) -> None:
         super().__init__(
             name='',
             locale=locale,
             coords=coords,
-            text=text)
-        self.amount = amount
-        self.distance_type = distance_type
+            text=text,
+        )
+        self.amount: Decimal = amount
+        self.distance_type: str = distance_type
 
     def get_cite_value_parts(self) -> List[str]:
         parts = [str(self.amount or ''),
