@@ -1,11 +1,12 @@
+from decimal import Decimal
 from typing import Tuple, List
 from lexnlp.extract.common.annotations.text_annotation import TextAnnotation
 from lexnlp.utils.map import Map
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2020, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/1.7.0/LICENSE"
-__version__ = "1.7.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/1.8.0/LICENSE"
+__version__ = "1.8.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
@@ -16,21 +17,24 @@ class RatioAnnotation(TextAnnotation):
     create an object of RatioAnnotation like
     cp = RatioAnnotation(name='name', coords=(0, 100), text='text text')
     """
-    def __init__(self,
-                 coords: Tuple[int, int],
-                 locale: str = 'en',
-                 text: str = None,
-                 left: float = None,
-                 right: float = None,
-                 ratio: float = None):
+    def __init__(
+        self,
+        coords: Tuple[int, int],
+        locale: str = 'en',
+        text: str = None,
+        left: Decimal = None,
+        right: Decimal = None,
+        ratio: Decimal = None
+    ) -> None:
         super().__init__(
             name='',
             locale=locale,
             coords=coords,
-            text=text)
-        self.left = left
-        self.right = right
-        self.ratio = ratio
+            text=text
+        )
+        self.left: Decimal = left
+        self.right: Decimal = right
+        self.ratio: Decimal = ratio
 
     def get_cite_value_parts(self) -> List[str]:
         parts = [str(self.left or ''),
