@@ -4,8 +4,8 @@ from lexnlp.extract.common.annotations.duration_annotation import DurationAnnota
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2020, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/1.7.0/LICENSE"
-__version__ = "1.7.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/1.8.0/LICENSE"
+__version__ = "1.8.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
@@ -25,9 +25,11 @@ class DurationParser:
     LOCALE = 'en'
 
     @classmethod
-    def get_annotations(cls,
-                        text: str,
-                        float_digits=4) -> List[DurationAnnotation]:
+    def get_annotations(
+        cls,
+        text: str,
+        float_digits: int = 4,
+    ) -> List[DurationAnnotation]:
         all_ants = cls.get_all_annotations(text, float_digits)
         if len(all_ants) < 2:
             return all_ants
@@ -37,8 +39,8 @@ class DurationParser:
         # grouped durations are:
         # - bigger timeframe to less timeframe
         # - are separated by punctuation, spaces and conjunctions only
-        ant_group = [all_ants[0]]
-        all_grouped = [ant_group]
+        ant_group: List[DurationAnnotation] = [all_ants[0]]
+        all_grouped: List[List[DurationAnnotation]] = [ant_group]
 
         for a in all_ants[1:]:
             if cls.check_ant_continues_group(ant_group, a, text):
@@ -48,7 +50,7 @@ class DurationParser:
                 all_grouped.append(ant_group)
 
         # sum group annotations
-        annotations = []
+        annotations: List = []
         for grp in all_grouped:
             if len(grp) == 1:
                 annotations.append(grp[0])
@@ -58,13 +60,16 @@ class DurationParser:
         return annotations
 
     @classmethod
-    def sum_annotations(cls,
-                        ant_group: List[DurationAnnotation]) -> \
-            DurationAnnotation:
+    def sum_annotations(
+        cls,
+        ant_group: List[DurationAnnotation],
+    ) -> DurationAnnotation:
         coords = (ant_group[0].coords[0], ant_group[-1].coords[1])
-        rst = DurationAnnotation(coords,
-                                 locale=ant_group[0].locale,
-                                 is_complex=True)
+        rst: DurationAnnotation = DurationAnnotation(
+            coords,
+            locale=ant_group[0].locale,
+            is_complex=True
+        )
         rst.duration_days = sum([d.duration_days for d in ant_group])
         rst.amount = rst.duration_days
         rst.duration_type = ant_group[-1].duration_type
@@ -72,13 +77,15 @@ class DurationParser:
         return rst
 
     @classmethod
-    def check_ant_continues_group(cls,
-                                  ant_group: List[DurationAnnotation],
-                                  ant: DurationAnnotation,
-                                  text: str) -> bool:
+    def check_ant_continues_group(
+        cls,
+        ant_group: List[DurationAnnotation],
+        ant: DurationAnnotation,
+        text: str,
+    ) -> bool:
         # the following dur should have shorter timeframe than the preceding one
-        a = ant_group[-1]
-        b = ant
+        a: DurationAnnotation = ant_group[-1]
+        b: DurationAnnotation = ant
         adr = cls.DURATION_MAP.get(a.duration_type_en or a.duration_type) or 1
         bdr = cls.DURATION_MAP.get(b.duration_type_en or b.duration_type) or 1
         if bdr >= adr:
@@ -86,15 +93,16 @@ class DurationParser:
 
         # the captures should be separated by: spaces, punctuation and
         # conjunctions ("and" in any case)
-        intext = text[a.coords[1]:b.coords[0]].lower()
+        intext: str = text[a.coords[1]:b.coords[0]].lower()
         for conj in cls.INNER_CONJUNCTIONS:
-            intext = intext.replace(conj, '')
-        intext = cls.INNER_PUNCTUATION.sub('', intext)
+            intext: str = intext.replace(conj, '')
+        intext: str = cls.INNER_PUNCTUATION.sub('', intext)
         return not intext
 
     @classmethod
-    def get_all_annotations(cls,
-                            text: str,
-                            float_digits=4) \
-            -> List[DurationAnnotation]:
+    def get_all_annotations(
+        cls,
+        text: str,
+        float_digits: int = 4,
+    ) -> List[DurationAnnotation]:
         raise NotImplementedError()
