@@ -6,15 +6,16 @@ This module implements basic distance extraction functionality in English.
 
 # Imports
 import re
-from typing import Generator
+from decimal import Decimal
+from typing import Generator, Union, Tuple
 
 from lexnlp.extract.common.annotations.distance_annotation import DistanceAnnotation
 from lexnlp.extract.en.amounts import get_amounts, NUM_PTN
 
 __author__ = "ContraxSuite, LLC; LexPredict, LLC"
 __copyright__ = "Copyright 2015-2020, ContraxSuite, LLC"
-__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/1.7.0/LICENSE"
-__version__ = "1.7.0"
+__license__ = "https://github.com/LexPredict/lexpredict-lexnlp/blob/1.8.0/LICENSE"
+__version__ = "1.8.0"
 __maintainer__ = "LexPredict, LLC"
 __email__ = "support@contraxsuite.com"
 
@@ -42,17 +43,22 @@ DISTANCE_PTN = r"""
 DISTANCE_PTN_RE = re.compile(DISTANCE_PTN, re.IGNORECASE | re.MULTILINE | re.DOTALL | re.VERBOSE)
 
 
-def get_distances(text: str, return_sources=False, float_digits=4) -> Generator:
+def get_distances(
+    text: str,
+    return_sources: bool = False,
+    float_digits: int = 4
+) -> Generator[Union[Tuple[Decimal, str], Tuple[Decimal, str, str]], None, None]:
     for ant in get_distance_annotations(text, float_digits):
-        item = (ant.amount, ant.distance_type)
         if return_sources:
-            item += (ant.text,)
-        yield item
+            yield ant.amount, ant.distance_type, ant.text
+        else:
+            yield ant.amount, ant.distance_type
 
 
-def get_distance_annotations(text: str, float_digits=4) \
-        -> Generator[DistanceAnnotation, None, None]:
-
+def get_distance_annotations(
+    text: str,
+    float_digits: int = 4
+) -> Generator[DistanceAnnotation, None, None]:
     for match in DISTANCE_PTN_RE.finditer(text.lower()):
         source_text, number_text, distance_item = match.groups()
         amount = list(get_amounts(number_text, float_digits=float_digits))
@@ -60,11 +66,9 @@ def get_distance_annotations(text: str, float_digits=4) \
             continue
         distance_type = DISTANCE_SYMBOL_MAP.get(distance_item) \
                         or DISTANCE_TOKEN_MAP.get(distance_item)
-        amount = amount[0]
-        if float_digits:
-            amount = round(amount, float_digits)
-        ant = DistanceAnnotation(coords=match.span(),
-                                 amount=amount,
-                                 distance_type=distance_type,
-                                 text=source_text.strip())
-        yield ant
+        yield DistanceAnnotation(
+            coords=match.span(),
+            amount=amount[0],
+            distance_type=distance_type,
+            text=source_text.strip()
+        )
